==> task-3.30.0.tar.gz: task-3.30.0/docs/i18n/fr-FR/docusaurus-plugin-content-docs/current/donate.md <==
---
slug: /donate/
sidebar_position: 16
---

# Faire un don

Si vous trouvez ce projet utile, vous pouvez envisager de faire un don en utilisant l'un des canaux listés ci-dessous.

C'est juste une façon de nous dire "merci", il ne vous donnera pas d'avantages comme une priorité élevée sur des problèmes ou des choses similaires.

Les entreprises qui font un don d'au moins 50$/mois seront présentées comme un "Sponsor Or" sur la page d'accueil du site and sur le README du dépôt GitHub. Prenez contact avec [@andreynering][] avec le logo que vous voulez afficher. Cependant, les entreprises suspectes (jeux, casinos, etc) ne seront pas autorisées.

## Sponsors GitHub

La façon préférée de faire un don aux mainteneurs du projet est d'utiliser les sponsors GitHub. Utilisez simplement le lien suivant pour faire votre don :

- [@andreynering](https://github.com/sponsors/andreynering)
- [@pd93](https://github.com/sponsors/pd93)

## Open Collective

Si vous préférez [Open Collective](https://opencollective.com/task) vous pouvez faire un don en utilisant ces liens :

- [2$ par mois](https://opencollective.com/task/contribute/backer-4034/checkout)
- [5$ par mois](https://opencollective.com/task/contribute/supporter-8404/checkout)
- [20$ par mois](https://opencollective.com/task/contribute/sponsor-4035/checkout)
- [50$ par mois](https://opencollective.com/task/contribute/sponsor-28775/checkout)
- [Valeur personnalisée - option de don unique prise en charge](https://opencollective.com/task/donate)

## PayPal

Vous pouvez aussi faire un don à [@andreynering][] via PayPal :

- [N'importe quelle valeur - Don unique](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=GSVDU63RKG45A&currency_code=USD&source=url)

## PIX (Brésil uniquement)

Et si vous êtes Brésilien, vous pouvez également faire un don à [@andreynering][] via PIX en [utilisant ce QR Code](/img/pix.png).

<!-- prettier-ignore-start -->

<!-- prettier-ignore-end -->
[@andreynering]: https://github.com/andreynering

==> task-3.33.1.tar.gz: task-3.33.1/docs/i18n/fr-FR/docusaurus-plugin-content-docs/current/donate.md <==
---
slug: /donate/
sidebar_position: 16
---

# Faire un don

Si vous trouvez ce projet utile, vous pouvez envisager de faire un don en utilisant l'un des canaux listés ci-dessous.

C'est juste une façon de nous dire "merci", il ne vous donnera pas d'avantages comme une priorité élevée sur des problèmes ou des choses similaires.

Les entreprises qui font un don d'au moins 50$/mois seront présentées comme un "Sponsor Or" sur la page d'accueil du site and sur le README du dépôt GitHub. Prenez contact avec [@andreynering][] avec le logo que vous voulez afficher. Cependant, les entreprises suspectes (jeux, casinos, etc) ne seront pas autorisées.

## Sponsors GitHub

La façon préférée de faire un don aux mainteneurs du projet est d'utiliser les sponsors GitHub. Vous pouvez utiliser le lien suivant pour faire votre don. Nous suggérons de donner 50% à chaque mainteneur du montant total que vous prévoyez de donner.

- [@andreynering](https://github.com/sponsors/andreynering)
- [@pd93](https://github.com/sponsors/pd93)

## Open Collective

Si vous préférez [Open Collective](https://opencollective.com/task) vous pouvez faire un don en utilisant ces liens :

- [2$ par mois](https://opencollective.com/task/contribute/backer-4034/checkout)
- [5$ par mois](https://opencollective.com/task/contribute/supporter-8404/checkout)
- [20$ par mois](https://opencollective.com/task/contribute/sponsor-4035/checkout)
- [50$ par mois](https://opencollective.com/task/contribute/sponsor-28775/checkout)
- [Valeur personnalisée - option de don unique prise en charge](https://opencollective.com/task/donate)

## PayPal

Vous pouvez aussi faire un don à [@andreynering][] via PayPal :

- [N'importe quelle valeur - Don unique](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=GSVDU63RKG45A&currency_code=USD&source=url)

## PIX (Brésil uniquement)

Et si vous êtes Brésilien, vous pouvez également faire un don à [@andreynering][] via PIX en [utilisant ce QR Code](/img/pix.png).

<!-- prettier-ignore-start -->

<!-- prettier-ignore-end -->
[@andreynering]: https://github.com/andreynering
